aboutsummaryrefslogtreecommitdiffstats
path: root/resources/libraries/bash/function
diff options
context:
space:
mode:
authorPeter Mikus <pmikus@cisco.com>2019-02-04 10:16:48 +0000
committerPeter Mikus <pmikus@cisco.com>2019-02-19 18:14:20 +0000
commitfa0fe5c805169951c466d3b18091c0cfc52dd5ca (patch)
tree50a053f45cfc033b6bd654049352eaa88c56e90e /resources/libraries/bash/function
parent9e158c1ee4ea59a23fd747ebfe6ddb00dd9cc668 (diff)
CSIT-1419 Convert vpp-virl job to vpp-device
Change-Id: I5af6de4b96775a72855e1644ca4d8d9b4b2f9e25 Signed-off-by: Peter Mikus <pmikus@cisco.com>
Diffstat (limited to 'resources/libraries/bash/function')
-rw-r--r--resources/libraries/bash/function/per_patch.sh111
1 files changed, 46 insertions, 65 deletions
diff --git a/resources/libraries/bash/function/per_patch.sh b/resources/libraries/bash/function/per_patch.sh
index 854392eca6..83e8427824 100644
--- a/resources/libraries/bash/function/per_patch.sh
+++ b/resources/libraries/bash/function/per_patch.sh
@@ -54,45 +54,21 @@ function build_vpp_ubuntu_amd64 () {
set -exuo pipefail
- # TODO: Make sure whether this works on other distros/archs too.
-
+ # This function is using Vagrant script to build VPP with all dependencies
+ # that is ARCH/OS aware. VPP repo is SSOT for building mechanics and CSIT
+ # is consuming artifacts. This way if VPP will introduce change in building
+ # mechanics they will not be blocked by CSIT repo.
# Arguments:
# - ${1} - String identifier for echo, can be unset.
# Variables read:
# - VPP_DIR - Path to existing directory, parent to accessed directories.
# Directories updated:
# - ${VPP_DIR} - Whole subtree, many files (re)created by the build process.
- # - ${VPP_DIR}/build-root - Final build artifacts for CSIT end up here.
- # - ${VPP_DIR}/dpdk - The dpdk artifact is built, but moved to build-root/.
# Functions called:
# - die - Print to stderr and exit, defined in common.sh
cd "${VPP_DIR}" || die "Change directory command failed."
echo 'Building using "make build-root/vagrant/build.sh"'
- # TODO: Do we want to support "${DRYRUN}" == "True"?
- make UNATTENDED=yes install-dep || die "Make install-dep failed."
- # The per_patch script calls this function twice, first for the new commit,
- # then for its parent commit. On Jenkins, no dpdk is installed at first,
- # locally it might have been installed. New dpdk is installed second call.
- # If make detects installed vpp-ext-deps with matching version,
- # it skips building vpp-ext-deps entirely.
- # On the other hand, if parent uses different dpdk version,
- # the new vpp-ext-deps is built, but the old one is not removed
- # from the build directory if present. (Further functions move both,
- # and during test dpkg would decide randomly which version gets installed.)
- # As per_patch is too dumb (yet) to detect any of that,
- # the only safe solution is to clean build directory and force rebuild.
- # TODO: Make this function smarter and skip DPDK rebuilds if possible.
- cmd=("dpkg-query" "--showformat='$${Version}'" "--show" "vpp-ext-deps")
- installed_deb_ver="$(sudo "${cmd[@]}" || true)"
- if [[ -n "${installed_deb_ver}" ]]; then
- sudo dpkg --purge "vpp-ext-deps" || {
- die "DPDK package uninstalation failed."
- }
- fi
- make UNATTENDED=yes install-ext-deps || {
- die "Make install-ext-deps failed."
- }
build-root/vagrant/"build.sh" || die "Vagrant VPP build script failed."
echo "*******************************************************************"
echo "* VPP ${1-} BUILD SUCCESSFULLY COMPLETED" || {
@@ -142,19 +118,20 @@ function download_builds () {
# - VPP_DIR - Path to WORKSPACE, parent of created directories.
# Directories created:
# - archive - Ends up empty, not to be confused with ${ARCHIVE_DIR}.
# - build_new - Holding built artifacts of the patch under test (PUT).
# - built_parent - Holding built artifacts of parent of PUT.
# Functions called:
# - die - Print to stderr and exit, defined in common.sh
cd "${VPP_DIR}" || die "Change directory operation failed."
- rm -rf "build-root" "build_parent" "build_new" "archive" "csit_new" || {
+ dirs=("build-root" "build_parent" "build_current" "archive" "csit_current")
+ rm -rf ${dirs[@]} || {
die "Directory removal failed."
}
wget -N --progress=dot:giga "${1}" || die "Wget download failed."
unzip "archive.zip" || die "Archive extraction failed."
mv "archive/build_parent" ./ || die "Move operation failed."
- mv "archive/build_new" ./ || die "Move operation failed."
+ mv "archive/build_current" ./ || die "Move operation failed."
}
@@ -167,16 +144,16 @@ function initialize_csit_dirs () {
# Variables read:
# - VPP_DIR - Path to WORKSPACE, parent of created directories.
# Directories created:
# - csit_new - Holding test results of the patch under test (PUT).
# - csit_parent - Holding test results of parent of PUT.
# Functions called:
# - die - Print to stderr and exit, defined in common.sh
cd "${VPP_DIR}" || die "Change directory operation failed."
- rm -rf "csit_new" "csit_parent" || {
+ rm -rf "csit_current" "csit_parent" || {
die "Directory deletion failed."
}
- mkdir -p "csit_new" "csit_parent" || {
+ mkdir -p "csit_current" "csit_parent" || {
die "Directory creation failed."
}
}
@@ -212,24 +189,51 @@ function parse_bmrr_results () {
}
-function prepare_build_parent () {
+function select_build () {
set -exuo pipefail
+ # Arguments:
+ # - ${1} - Path to directory to copy VPP artifacts from. Required.
+ # Variables read:
+ # - DOWNLOAD_DIR - Path to directory where Robot takes builds to test from.
+ # - VPP_DIR - Path to existing directory, root for relative paths.
+ # Directories read:
+ # - ${1} - Existing directory with built new VPP artifacts (and DPDK).
+ # Directories updated:
+ # - ${DOWNLOAD_DIR} - Old content removed, .deb files from ${1} copied here.
+ # Functions called:
+ # - die - Print to stderr and exit, defined in common.sh
+
+ cd "${VPP_DIR}" || die "Change directory operation failed."
+ source_dir="$(readlink -e "$1")"
+ rm -rf "${DOWNLOAD_DIR}"/* || die "Cleanup of download dir failed."
+ cp "${source_dir}"/*".deb" "${DOWNLOAD_DIR}" || die "Copy operation failed."
+ # TODO: Is there a nice way to create symlinks,
+ # so that if job fails on robot, results can be archived?
+}
+
+
+function set_aside_commit_build_artifacts () {
+
+ set -exuo pipefail
+
+ # Function is copying VPP built artifacts from actual checkout commit for
+ # further use and clean git.
# Variables read:
# - VPP_DIR - Path to existing directory, parent to accessed directories.
# Directories read:
# - build-root - Existing directory with built VPP artifacts (also DPDK).
# Directories updated:
# - ${VPP_DIR} - A local git repository, parent commit gets checked out.
# - build_new - Old contents removed, content of build-root copied here.
# Functions called:
# - die - Print to stderr and exit, defined in common.sh
cd "${VPP_DIR}" || die "Change directory operation failed."
- rm -rf "build_new" || die "Remove operation failed."
- mkdir -p "build_new" || die "Directory creation failed."
- mv "build-root"/*".deb" "build_new"/ || die "Move operation failed."
+ rm -rf "build_current" || die "Remove operation failed."
+ mkdir -p "build_current" || die "Directory creation failed."
+ mv "build-root"/*".deb" "build_current"/ || die "Move operation failed."
# The previous build could have left some incompatible leftovers,
# e.g. DPDK artifacts of different version (in build/external).
# Also, there usually is a copy of dpdk artifact in build-root.
@@ -241,10 +245,12 @@ function prepare_build_parent () {
}
-function prepare_test () {
+function set_aside_parent_build_artifacts () {
set -exuo pipefail
+ # Function is copying VPP built artifacts from parent checkout commit for
+ # further use. Checkout to parent is not part of this function.
# Variables read:
# - VPP_DIR - Path to existing directory, parent of accessed directories.
# Directories read:
@@ -261,31 +267,6 @@ function prepare_test () {
}
-function select_build () {
-
- set -exuo pipefail
-
- # Arguments:
- # - ${1} - Path to directory to copy VPP artifacts from. Required.
- # Variables read:
- # - DOWNLOAD_DIR - Path to directory where Robot takes builds to test from.
- # - VPP_DIR - Path to existing directory, root for relative paths.
- # Directories read:
- # - ${1} - Existing directory with built new VPP artifacts (and DPDK).
- # Directories updated:
- # - ${DOWNLOAD_DIR} - Old content removed, .deb files from ${1} copied here.
- # Functions called:
- # - die - Print to stderr and exit, defined in common.sh
-
- cd "${VPP_DIR}" || die "Change directory operation failed."
- source_dir="$(readlink -e "$1")"
- rm -rf "${DOWNLOAD_DIR}"/* || die "Cleanup of download dir failed."
- cp "${source_dir}"/*".deb" "${DOWNLOAD_DIR}" || die "Copy operation failed."
- # TODO: Is there a nice way to create symlinks,
- # so that if job fails on robot, results can be archived?
-}
-
-
function set_perpatch_dut () {
set -exuo pipefail
@@ -142,19 +118,20 @@ function download_builds () {
# Directories created:
# - archive - Ends up empty, not to be confused with ${ARCHIVE_DIR}.
- # - build_new - Holding built artifacts of the patch under test (PUT).
+ # - build_current - Holding built artifacts of the patch under test (PUT).
# - built_parent - Holding built artifacts of parent of PUT.
# Functions called:
@@ -167,16 +144,16 @@ function initialize_csit_dirs () {
# - VPP_DIR - Path to WORKSPACE, parent of created directories.
# Directories created:
- # - csit_new - Holding test results of the patch under test (PUT).
+ # - csit_current - Holding test results of the patch under test (PUT).
# - csit_parent - Holding test results of parent of PUT.
# Functions called:
@@ -212,24 +189,51 @@ function parse_bmrr_results () {
# Directories updated:
# - ${VPP_DIR} - A local git repository, parent commit gets checked out.
- # - build_new - Old contents removed, content of build-root copied here.
+ # - build_current - Old contents removed, content of build-root copied here.
# Functions called:
# - die - Print to stderr and exit, defined in common.sh